@@ -12,7 +12,7 @@ SPVM_HASH* SPVM_HASH_new(int32_t table_capacity) {
   assert(table_capacity >= 0);
 
   // Create hash
-  SPVM_HASH* hash = SPVM_UTIL_ALLOCATOR_safe_malloc_i32_zero(1, sizeof(SPVM_HASH));
+  SPVM_HASH* hash = SPVM_UTIL_ALLOCATOR_safe_malloc_zero(sizeof(SPVM_HASH));
 
   // Default table capacity
   if (table_capacity == 0) {
@@ -23,17 +23,20 @@ SPVM_HASH* SPVM_HASH_new(int32_t table_capacity) {
   }
   
   // Initialize table
-  hash->table = SPVM_UTIL_ALLOCATOR_safe_malloc_i32_zero(hash->table_capacity, sizeof(int32_t));
+  int64_t hash_table_byte_size = (int64_t)hash->table_capacity * (int64_t)sizeof(int32_t);
+  hash->table = SPVM_UTIL_ALLOCATOR_safe_malloc_zero(hash_table_byte_size);
   memset(hash->table, -1, hash->table_capacity * sizeof(int32_t));
   
   // Initialize entries
   hash->entries_capacity = 255;
-  hash->entries = SPVM_UTIL_ALLOCATOR_safe_malloc_i32_zero(hash->entries_capacity, sizeof(SPVM_HASH_ENTRY));
+  int64_t hash_entries_byte_size = (int64_t)hash->entries_capacity * (int64_t)sizeof(SPVM_HASH_ENTRY);
+  hash->entries = SPVM_UTIL_ALLOCATOR_safe_malloc_zero(hash_entries_byte_size);
   hash->entries_length = 0;
   
   // Initialize key buffer
   hash->key_buffer_capacity = 0xFF;
-  hash->key_buffer = SPVM_UTIL_ALLOCATOR_safe_malloc_i32_zero(hash->key_buffer_capacity, sizeof(char));
+  int64_t hash_key_buffer_byte_size = (int64_t)hash->key_buffer_capacity * (int64_t)sizeof(char);
+  hash->key_buffer = SPVM_UTIL_ALLOCATOR_safe_malloc_zero(hash_key_buffer_byte_size);
   hash->key_buffer_length = 0;
   
   return hash;
@@ -51,8 +54,9 @@ void SPVM_HASH_maybe_extend_entries(SPVM_HASH* hash) {
   
   if (entries_length >= entries_capacity) {
     int32_t new_entries_capacity = entries_capacity * 2;
-
-    SPVM_HASH_ENTRY* new_entries = SPVM_UTIL_ALLOCATOR_safe_malloc_i32_zero(new_entries_capacity, sizeof(SPVM_HASH_ENTRY));
+    
+    int64_t new_entries_byte_size = (int64_t)new_entries_capacity * (int64_t)sizeof(SPVM_HASH_ENTRY);
+    SPVM_HASH_ENTRY* new_entries = SPVM_UTIL_ALLOCATOR_safe_malloc_zero(new_entries_byte_size);
     memcpy(new_entries, hash->entries, entries_capacity * sizeof(SPVM_HASH_ENTRY));
     free(hash->entries);
     hash->entries = new_entries;
@@ -73,8 +77,9 @@ void SPVM_HASH_maybe_extend_key_buffer(SPVM_HASH* hash, int32_t length) {
   
   if (key_buffer_length + length >= key_buffer_capacity) {
     int32_t new_key_buffer_capacity = key_buffer_capacity * 2;
-
-    char* new_key_buffer = SPVM_UTIL_ALLOCATOR_safe_malloc_i32_zero(new_key_buffer_capacity, sizeof(SPVM_HASH_ENTRY));
+    
+    int64_t new_key_buffer_byte_size = (int64_t)new_key_buffer_capacity * (int64_t)sizeof(SPVM_HASH_ENTRY);
+    char* new_key_buffer = SPVM_UTIL_ALLOCATOR_safe_malloc_zero(new_key_buffer_byte_size);
     memcpy(new_key_buffer, hash->key_buffer, key_buffer_capacity);
     free(hash->key_buffer);
     hash->key_buffer = new_key_buffer;
