@@ -102,7 +102,6 @@ const char* const SPVM_OP_C_CODE_NAMES[] = {
   "CONVERT",
   "POP",
   "UNDEF",
-  "MALLOC",
   "ARRAY_LENGTH",
   "CONDITION",
   "DIE",
@@ -115,9 +114,12 @@ const char* const SPVM_OP_C_CODE_NAMES[] = {
   "BLOCK_END",
   "EXCEPTION_VAR",
   "ASSIGN_PROCESS",
+  "NEW",
 };
 
 void SPVM_OP_resolve_constant(SPVM_COMPILER* compiler, SPVM_OP* op_constant) {
+  (void)compiler;
+  
   SPVM_CONSTANT* constant = op_constant->uv.constant;
   if (constant->resolved) {
     return;
@@ -142,11 +144,6 @@ void SPVM_OP_resolve_constant(SPVM_COMPILER* compiler, SPVM_OP* op_constant) {
   constant->resolved = 1;
 }
 
-SPVM_OP* SPVM_OP_fold_constant(SPVM_COMPILER* compiler, SPVM_OP* op_cur) {
-  
-  return op_cur;
-}
-
 SPVM_OP* SPVM_OP_build_constant(SPVM_COMPILER* compiler, SPVM_OP* op_constant) {
   
   SPVM_DYNAMIC_ARRAY_push(compiler->op_constants, op_constant);
@@ -254,6 +251,9 @@ SPVM_OP* SPVM_OP_build_eval(SPVM_COMPILER* compiler, SPVM_OP* op_eval, SPVM_OP*
   SPVM_OP_insert_child(compiler, op_assign, op_assign->last, op_exception_var);
   SPVM_OP_insert_child(compiler, op_assign, op_assign->last, op_undef);
   
+  op_assign->first->lvalue = 1;
+  op_assign->last->rvalue = 1;
+  
   SPVM_OP* op_list_statement = op_eval_block->first;
   SPVM_OP_insert_child(compiler, op_list_statement, op_list_statement->first, op_assign);
   
@@ -408,11 +408,11 @@ SPVM_OP* SPVM_OP_build_array_length(SPVM_COMPILER* compiler, SPVM_OP* op_array_l
   return op_array_length;
 }
 
-SPVM_OP* SPVM_OP_build_malloc_object(SPVM_COMPILER* compiler, SPVM_OP* op_malloc, SPVM_OP* op_type) {
+SPVM_OP* SPVM_OP_build_new_object(SPVM_COMPILER* compiler, SPVM_OP* op_new, SPVM_OP* op_type) {
   
-  SPVM_OP_insert_child(compiler, op_malloc, op_malloc->last, op_type);
+  SPVM_OP_insert_child(compiler, op_new, op_new->last, op_type);
   
-  return op_malloc;
+  return op_new;
 }
 
 SPVM_TYPE* SPVM_OP_get_type(SPVM_COMPILER* compiler, SPVM_OP* op) {
@@ -449,7 +449,7 @@ SPVM_TYPE* SPVM_OP_get_type(SPVM_COMPILER* compiler, SPVM_OP* op) {
     case SPVM_OP_C_CODE_PLUS:
     case SPVM_OP_C_CODE_NEGATE:
     case SPVM_OP_C_CODE_ASSIGN:
-    case SPVM_OP_C_CODE_MALLOC:
+    case SPVM_OP_C_CODE_NEW:
     {
       type = SPVM_OP_get_type(compiler, op->first);
       break;
@@ -526,137 +526,6 @@ SPVM_TYPE* SPVM_OP_get_type(SPVM_COMPILER* compiler, SPVM_OP* op) {
   return type;
 }
 
-void SPVM_OP_convert_and_to_if(SPVM_COMPILER* compiler, SPVM_OP* op_if1) {
-  
-  /* before
-    AND
-      x
-      y
-  */
-  
-  /* after 
-    IF              if1
-      CONDITION
-        x
-      IF            if2
-        CONDITION
-          y
-        1           true1
-        0           false1
-      0             false2
-  */
-  
-  SPVM_OP* op_x = op_if1->first;
-  SPVM_OP* op_y = op_if1->last;
-  
-  // Convert to ADN to IF
-  op_if1->code = SPVM_OP_C_CODE_IF;
-  
-  // Cut op
-  op_x->moresib = 0;
-  op_x->sibparent = NULL;
-  op_y->moresib = 0;
-  op_y->sibparent = NULL;
-  op_if1->first = NULL;
-  op_if1->last = NULL;
-  
-  // Constant true
-  SPVM_OP* op_constant_true = SPVM_OP_new_op_constant_int(compiler, 1, op_if1->file, op_if1->line);
-
-  // Constant false 1
-  SPVM_OP* op_constant_false1 = SPVM_OP_new_op_constant_int(compiler, 0, op_if1->file, op_if1->line);
-  
-  // Constant false 2
-  SPVM_OP* op_constant_false2 = SPVM_OP_new_op_constant_int(compiler, 0, op_if1->file, op_if1->line);
-  
-  // if2
-  SPVM_OP* op_if2 = SPVM_OP_new_op(compiler, SPVM_OP_C_CODE_IF, op_if1->file, op_if1->line);
-  
-  // Build if tree
-  SPVM_OP_build_if_statement(compiler, op_if2, op_y, op_constant_true, op_constant_false1);
-  SPVM_OP_build_if_statement(compiler, op_if1, op_x, op_if2, op_constant_false2);
-}
-
-void SPVM_OP_convert_or_to_if(SPVM_COMPILER* compiler, SPVM_OP* op_if1) {
-  
-  // before
-  //  OR
-  //    x
-  //    y
-  
-  // after 
-  //  IF      if1
-  //    x
-  //    1     true1
-  //    IF    if2
-  //      y
-  //      1   true2
-  //      0   false
-  
-  SPVM_OP* op_x = op_if1->first;
-  SPVM_OP* op_y = op_if1->last;
-  
-  // Convert to ADN to IF
-  op_if1->code = SPVM_OP_C_CODE_IF;
-  
-  // Cut op
-  op_x->moresib = 0;
-  op_x->sibparent = NULL;
-  op_y->moresib = 0;
-  op_y->sibparent = NULL;
-  op_if1->first = NULL;
-  op_if1->last = NULL;
-  
-  // Constant true 1
-  SPVM_OP* op_constant_true1 = SPVM_OP_new_op_constant_int(compiler, 1, op_if1->file, op_if1->line);
-  
-  // Constant true 2
-  SPVM_OP* op_constant_true2 = SPVM_OP_new_op_constant_int(compiler, 1, op_if1->file, op_if1->line);
-  
-  // Constant false
-  SPVM_OP* op_constant_false = SPVM_OP_new_op_constant_int(compiler, 0, op_if1->file, op_if1->line);
-  
-  // if2
-  SPVM_OP* op_if2 = SPVM_OP_new_op(compiler, SPVM_OP_C_CODE_IF, op_if1->file, op_if1->line);
-  
-  // Build if tree
-  SPVM_OP_build_if_statement(compiler, op_if2, op_y, op_constant_true2, op_constant_false);
-  SPVM_OP_build_if_statement(compiler, op_if1, op_x, op_constant_true1, op_if2);
-}
-
-void SPVM_OP_convert_not_to_if(SPVM_COMPILER* compiler, SPVM_OP* op_if) {
-  
-  // before
-  //  NOT
-  //    x
-  
-  // after 
-  //  IF
-  //    x
-  //    0
-  //    1
-  
-  SPVM_OP* op_x = op_if->first;
-  
-  // Convert to ADN to IF
-  op_if->code = SPVM_OP_C_CODE_IF;
-  
-  // Cut op
-  op_x->moresib = 0;
-  op_x->sibparent = NULL;
-  op_if->first = NULL;
-  op_if->last = NULL;
-  
-  // Constant false
-  SPVM_OP* op_constant_false = SPVM_OP_new_op_constant_int(compiler, 0, op_if->file, op_if->line);
-
-  // Constant true
-  SPVM_OP* op_constant_true = SPVM_OP_new_op_constant_int(compiler, 1, op_if->file, op_if->line);
-  
-  // Build if tree
-  SPVM_OP_build_if_statement(compiler, op_if, op_x, op_constant_false, op_constant_true);
-}
-
 void SPVM_OP_resolve_sub_name(SPVM_COMPILER* compiler, SPVM_OP* op_package, SPVM_OP* op_name) {
   
   SPVM_NAME_INFO* name_info = op_name->uv.name_info;
@@ -1057,7 +926,7 @@ SPVM_OP* SPVM_OP_build_use(SPVM_COMPILER* compiler, SPVM_OP* op_use, SPVM_OP* op
   if (part_names->length > 1) {
     int32_t i;
     for (i = 1; i < part_names->length; i++) {
-      const char* part_name = SPVM_DYNAMIC_ARRAY_fetch(part_names, i);
+      char* part_name = SPVM_DYNAMIC_ARRAY_fetch(part_names, i);
       SPVM_DYNAMIC_ARRAY_push(use->template_args, part_name);
     }
   }
@@ -1118,6 +987,11 @@ SPVM_OP* SPVM_OP_build_field(SPVM_COMPILER* compiler, SPVM_OP* op_field, SPVM_OP
 
 SPVM_OP* SPVM_OP_build_sub(SPVM_COMPILER* compiler, SPVM_OP* op_sub, SPVM_OP* op_name_sub, SPVM_OP* op_args, SPVM_OP* op_descriptors, SPVM_OP* op_type_or_void, SPVM_OP* op_block) {
   
+  if (op_name_sub->code == SPVM_OP_C_CODE_NEW) {
+    op_name_sub->code = SPVM_OP_C_CODE_NAME;
+    op_name_sub->uv.name = "new";
+  }
+  
   // Build OP_SUB
   SPVM_OP_insert_child(compiler, op_sub, op_sub->last, op_name_sub);
   SPVM_OP_insert_child(compiler, op_sub, op_sub->last, op_args);
@@ -1199,6 +1073,11 @@ SPVM_OP* SPVM_OP_build_enumeration(SPVM_COMPILER* compiler, SPVM_OP* op_enumerat
 
 SPVM_OP* SPVM_OP_build_call_sub(SPVM_COMPILER* compiler, SPVM_OP* op_invocant, SPVM_OP* op_name_sub, SPVM_OP* op_terms) {
   
+  if (op_name_sub->code == SPVM_OP_C_CODE_NEW) {
+    op_name_sub->code = SPVM_OP_C_CODE_NAME;
+    op_name_sub->uv.name = "new";
+  }
+  
   // Build OP_SUB
   SPVM_OP* op_call_sub = SPVM_OP_new_op(compiler, SPVM_OP_C_CODE_CALL_SUB, op_name_sub->file, op_name_sub->line);
   SPVM_OP_insert_child(compiler, op_call_sub, op_call_sub->last, op_name_sub);
@@ -1291,7 +1170,115 @@ SPVM_OP* SPVM_OP_build_binop(SPVM_COMPILER* compiler, SPVM_OP* op_bin, SPVM_OP*
   return op_bin;
 }
 
-SPVM_OP* SPVM_OP_build_assignop(SPVM_COMPILER* compiler, SPVM_OP* op_assign, SPVM_OP* op_first, SPVM_OP* op_last) {
+SPVM_OP* SPVM_OP_build_and(SPVM_COMPILER* compiler, SPVM_OP* op_and, SPVM_OP* op_first, SPVM_OP* op_last) {
+  
+  // Convert && to if statement
+  /* before
+    AND
+      first
+      last
+  */
+  
+  /* after 
+    IF              if1
+      CONDITION
+        first
+      IF            if2
+        CONDITION
+          last
+        1           true1
+        0           false1
+      0             false2
+  */
+  
+  SPVM_OP* op_if1 = SPVM_OP_new_op(compiler, SPVM_OP_C_CODE_IF, op_and->file, op_and->line);
+  
+  // Constant true
+  SPVM_OP* op_constant_true = SPVM_OP_new_op_constant_int(compiler, 1, op_if1->file, op_if1->line);
+
+  // Constant false 1
+  SPVM_OP* op_constant_false1 = SPVM_OP_new_op_constant_int(compiler, 0, op_if1->file, op_if1->line);
+  
+  // Constant false 2
+  SPVM_OP* op_constant_false2 = SPVM_OP_new_op_constant_int(compiler, 0, op_if1->file, op_if1->line);
+  
+  // if2
+  SPVM_OP* op_if2 = SPVM_OP_new_op(compiler, SPVM_OP_C_CODE_IF, op_if1->file, op_if1->line);
+  
+  // Build if tree
+  SPVM_OP_build_if_statement(compiler, op_if2, op_last, op_constant_true, op_constant_false1);
+  SPVM_OP_build_if_statement(compiler, op_if1, op_first, op_if2, op_constant_false2);
+  
+  return op_if1;
+}
+
+SPVM_OP* SPVM_OP_build_or(SPVM_COMPILER* compiler, SPVM_OP* op_or, SPVM_OP* op_first, SPVM_OP* op_last) {
+  
+  // Convert || to if statement
+  // before
+  //  OR
+  //    first
+  //    last
+  
+  // after 
+  //  IF      if1
+  //    first
+  //    1     true1
+  //    IF    if2
+  //      last
+  //      1   true2
+  //      0   false
+  
+  SPVM_OP* op_if1 = SPVM_OP_new_op(compiler, SPVM_OP_C_CODE_IF, op_or->file, op_or->line);
+  
+  // Constant true 1
+  SPVM_OP* op_constant_true1 = SPVM_OP_new_op_constant_int(compiler, 1, op_if1->file, op_if1->line);
+  
+  // Constant true 2
+  SPVM_OP* op_constant_true2 = SPVM_OP_new_op_constant_int(compiler, 1, op_if1->file, op_if1->line);
+  
+  // Constant false
+  SPVM_OP* op_constant_false = SPVM_OP_new_op_constant_int(compiler, 0, op_if1->file, op_if1->line);
+  
+  // if2
+  SPVM_OP* op_if2 = SPVM_OP_new_op(compiler, SPVM_OP_C_CODE_IF, op_if1->file, op_if1->line);
+  
+  // Build if tree
+  SPVM_OP_build_if_statement(compiler, op_if2, op_last, op_constant_true2, op_constant_false);
+  SPVM_OP_build_if_statement(compiler, op_if1, op_first, op_constant_true1, op_if2);
+  
+  return op_if1;
+}
+
+SPVM_OP* SPVM_OP_build_not(SPVM_COMPILER* compiler, SPVM_OP* op_not, SPVM_OP* op_first) {
+  
+  // Convert ! to if statement
+  // before
+  //  NOT
+  //    first
+  
+  // after 
+  //  IF
+  //    first
+  //    0
+  //    1
+  
+  SPVM_OP* op_if = SPVM_OP_new_op(compiler, SPVM_OP_C_CODE_IF, op_not->file, op_not->line);
+  
+  // Constant false
+  SPVM_OP* op_constant_false = SPVM_OP_new_op_constant_int(compiler, 0, op_if->file, op_if->line);
+
+  // Constant true
+  SPVM_OP* op_constant_true = SPVM_OP_new_op_constant_int(compiler, 1, op_if->file, op_if->line);
+  
+  // Build if tree
+  SPVM_OP_build_if_statement(compiler, op_if, op_first, op_constant_false, op_constant_true);
+  
+  return op_if;
+}
+
+
+SPVM_OP* SPVM_OP_build_assign(SPVM_COMPILER* compiler, SPVM_OP* op_assign, SPVM_OP* op_first, SPVM_OP* op_last) {
   
   // Stab to add after process
   SPVM_OP* op_assign_process = SPVM_OP_new_op(compiler, SPVM_OP_C_CODE_ASSIGN_PROCESS, op_assign->file, op_assign->line);
@@ -1300,6 +1287,9 @@ SPVM_OP* SPVM_OP_build_assignop(SPVM_COMPILER* compiler, SPVM_OP* op_assign, SPV
   SPVM_OP_insert_child(compiler, op_assign, op_assign->last, op_first);
   SPVM_OP_insert_child(compiler, op_assign, op_assign->last, op_last);
   
+  op_assign->first->lvalue = 1;
+  op_assign->last->rvalue = 1;
+  
   // Return variable if first children is var
   if (op_first->code == SPVM_OP_C_CODE_VAR) {
     SPVM_OP* op_var = SPVM_OP_new_op(compiler, SPVM_OP_C_CODE_VAR, op_assign->file, op_assign->line);
@@ -1319,7 +1309,7 @@ SPVM_OP* SPVM_OP_build_assignop(SPVM_COMPILER* compiler, SPVM_OP* op_assign, SPV
       int32_t length = 0;
       SPVM_TYPE* first_type = NULL;
       SPVM_OP* op_term = op_list->first;
-      while (op_term = SPVM_OP_sibling(compiler, op_term)) {
+      while ((op_term = SPVM_OP_sibling(compiler, op_term))) {
         SPVM_OP_resolve_constant(compiler, op_term);
         
         // Term must be constant
@@ -1351,48 +1341,48 @@ SPVM_OP* SPVM_OP_build_assignop(SPVM_COMPILER* compiler, SPVM_OP* op_assign, SPV
       op_constant_length->uv.constant = constant_length;
       
       // Malloc
-      SPVM_OP* op_malloc = SPVM_OP_new_op(compiler, SPVM_OP_C_CODE_MALLOC, op_list->file, op_list->line);
-      SPVM_OP* op_type_malloc = SPVM_OP_new_op(compiler, SPVM_OP_C_CODE_TYPE, op_list->file, op_list->line);
+      SPVM_OP* op_new = SPVM_OP_new_op(compiler, SPVM_OP_C_CODE_NEW, op_list->file, op_list->line);
+      SPVM_OP* op_type_new = SPVM_OP_new_op(compiler, SPVM_OP_C_CODE_TYPE, op_list->file, op_list->line);
       
       if (first_type->id == SPVM_TYPE_C_ID_BYTE) {
-        op_type_malloc->uv.type = SPVM_HASH_search(compiler->type_symtable, "byte[]", strlen("byte[]"));
+        op_type_new->uv.type = SPVM_HASH_search(compiler->type_symtable, "byte[]", strlen("byte[]"));
       }
       else if (first_type->id == SPVM_TYPE_C_ID_SHORT) {
-        op_type_malloc->uv.type = SPVM_HASH_search(compiler->type_symtable, "short[]", strlen("short[]"));
+        op_type_new->uv.type = SPVM_HASH_search(compiler->type_symtable, "short[]", strlen("short[]"));
       }
       else if (first_type->id == SPVM_TYPE_C_ID_INT) {
-        op_type_malloc->uv.type = SPVM_HASH_search(compiler->type_symtable, "int[]", strlen("int[]"));
+        op_type_new->uv.type = SPVM_HASH_search(compiler->type_symtable, "int[]", strlen("int[]"));
       }
       else if (first_type->id == SPVM_TYPE_C_ID_LONG) {
-        op_type_malloc->uv.type = SPVM_HASH_search(compiler->type_symtable, "long[]", strlen("long[]"));
+        op_type_new->uv.type = SPVM_HASH_search(compiler->type_symtable, "long[]", strlen("long[]"));
       }
       else if (first_type->id == SPVM_TYPE_C_ID_FLOAT) {
-        op_type_malloc->uv.type = SPVM_HASH_search(compiler->type_symtable, "float[]", strlen("float[]"));
+        op_type_new->uv.type = SPVM_HASH_search(compiler->type_symtable, "float[]", strlen("float[]"));
       }
       else if (first_type->id == SPVM_TYPE_C_ID_DOUBLE) {
-        op_type_malloc->uv.type = SPVM_HASH_search(compiler->type_symtable, "double[]", strlen("double[]"));
+        op_type_new->uv.type = SPVM_HASH_search(compiler->type_symtable, "double[]", strlen("double[]"));
       }
       else if (first_type->id == SPVM_TYPE_C_ID_STRING) {
-        op_type_malloc->uv.type = SPVM_HASH_search(compiler->type_symtable, "string[]", strlen("string[]"));
+        op_type_new->uv.type = SPVM_HASH_search(compiler->type_symtable, "string[]", strlen("string[]"));
       }
       else {
         assert(0);
       }
-      SPVM_OP_insert_child(compiler, op_malloc, op_malloc->last, op_type_malloc);
+      SPVM_OP_insert_child(compiler, op_new, op_new->last, op_type_new);
       
-      op_assign->last = op_malloc;
-      op_malloc->moresib = 0;
-      op_malloc->sibparent = op_assign;
-      op_first->sibparent = op_malloc;
+      op_assign->last = op_new;
+      op_new->moresib = 0;
+      op_new->sibparent = op_assign;
+      op_first->sibparent = op_new;
       
       // Add length constant
-      SPVM_OP_insert_child(compiler, op_type_malloc, op_type_malloc->last, op_constant_length);
+      SPVM_OP_insert_child(compiler, op_type_new, op_type_new->last, op_constant_length);
       
       // Assign array element
       SPVM_OP* op_list_new = SPVM_OP_new_op_list(compiler, op_list->file, op_list->line);
       SPVM_DYNAMIC_ARRAY* op_terms = SPVM_COMPILER_ALLOCATOR_alloc_array(compiler, compiler->allocator, 0);
       op_term = op_list->first;
-      while (op_term = SPVM_OP_sibling(compiler, op_term)) {
+      while ((op_term = SPVM_OP_sibling(compiler, op_term))) {
         SPVM_DYNAMIC_ARRAY_push(op_terms, op_term);
       }
       {
@@ -1419,6 +1409,9 @@ SPVM_OP* SPVM_OP_build_assignop(SPVM_COMPILER* compiler, SPVM_OP* op_assign, SPV
           op_term->sibparent = NULL;
           SPVM_OP_insert_child(compiler, op_assign_array, op_assign_array->last, op_term);
           
+          op_assign_array->first->lvalue = 1;
+          op_assign_array->last->rvalue = 1;
+          
           SPVM_OP_insert_child(compiler, op_list_new, op_list_new->last, op_assign_array);
         }
       }
@@ -1485,6 +1478,9 @@ SPVM_OP* SPVM_OP_build_die(SPVM_COMPILER* compiler, SPVM_OP* op_die, SPVM_OP* op
   SPVM_OP_insert_child(compiler, op_assign, op_assign->last, op_exception_var);
   SPVM_OP_insert_child(compiler, op_assign, op_assign->last, op_term);
   
+  op_assign->first->lvalue = 1;
+  op_assign->last->rvalue = 1;
+  
   SPVM_OP_insert_child(compiler, op_die, op_die->last, op_assign);
   
   return op_die;
@@ -1550,6 +1546,7 @@ SPVM_OP* SPVM_OP_new_op(SPVM_COMPILER* compiler, int32_t code, const char* file,
 
 // Insert child. Child must not have sibling.
 void SPVM_OP_insert_child(SPVM_COMPILER* compiler, SPVM_OP* parent, SPVM_OP* start, SPVM_OP* insert) {
+  (void)compiler;
   
   // del_count not used
   assert(parent);
