@@ -3,6 +3,7 @@
 #include <string.h>
 #include <stdint.h>
 #include <assert.h>
+#include <ctype.h>
 
 
 #include "spvm_compiler.h"
@@ -336,40 +337,6 @@ void SPVM_OP_CHECKER_check(SPVM_COMPILER* compiler) {
               // [START]Preorder traversal position
               
               switch (op_cur->code) {
-                case SPVM_OP_C_CODE_AND: {
-                  
-                  // Convert && to if statement
-                  SPVM_OP_convert_and_to_if(compiler, op_cur);
-                  
-                  assert(op_cur->first);
-                  
-                  break;
-                }
-                case SPVM_OP_C_CODE_OR: {
-                  
-                  // Convert || to if statement
-                  SPVM_OP_convert_or_to_if(compiler, op_cur);
-                  
-                  break;
-                }
-                case SPVM_OP_C_CODE_NOT: {
-                  // Convert ! to if statement
-                  SPVM_OP_convert_not_to_if(compiler, op_cur);
-                  
-                  break;
-                }
-                case SPVM_OP_C_CODE_SWITCH: {
-                  if (in_switch) {
-                    SPVM_yyerror_format(compiler, "duplicate switch is forbidden at %s line %d\n", op_cur->file, op_cur->line);
-                    compiler->fatal_error = 1;
-                    return;
-                  }
-                  else {
-                    in_switch = 1;
-                  }
-                  
-                  break;
-                }
                 // Start scope
                 case SPVM_OP_C_CODE_BLOCK: {
                   
@@ -415,6 +382,16 @@ void SPVM_OP_CHECKER_check(SPVM_COMPILER* compiler) {
                       SPVM_OP_insert_child(compiler, op_statements, op_statements->last, op_return);
                     }
                   }
+                  else if (op_cur->flag & SPVM_OP_C_FLAG_BLOCK_SWITCH) {
+                    if (in_switch) {
+                      SPVM_yyerror_format(compiler, "duplicate switch is forbidden at %s line %d\n", op_cur->file, op_cur->line);
+                      compiler->fatal_error = 1;
+                      return;
+                    }
+                    else {
+                      in_switch = 1;
+                    }
+                  }
                   
                   block_my_var_base = op_my_var_stack->length;
                   int32_t* block_my_var_base_ptr = SPVM_COMPILER_ALLOCATOR_alloc_int(compiler, compiler->allocator);
@@ -430,17 +407,9 @@ void SPVM_OP_CHECKER_check(SPVM_COMPILER* compiler) {
                   
                   break;
                 }
-                case SPVM_OP_C_CODE_ASSIGN: {
-                  // Left side of "=" is lvalue
-                  op_cur->first->lvalue = 1;
-                  
-                  // Right side of "=" is rvalue
-                  op_cur->last->rvalue = 1;
-                  break;
-                }
               }
-              
               // [END]Preorder traversal position
+              
               if (op_cur->first) {
                 op_cur = op_cur->first;
               }
@@ -463,16 +432,12 @@ void SPVM_OP_CHECKER_check(SPVM_COMPILER* compiler) {
                     case SPVM_OP_C_CODE_CONSTANT: {
                       SPVM_CONSTANT* constant = op_cur->uv.constant;
                       
-                      SPVM_CONSTANT_POOL* constant_pool = compiler->constant_pool;
-                      
                       switch (constant->type->id) {
                         case SPVM_TYPE_C_ID_STRING: {
-                          const char* value = constant->value.string_value;
-                          
                           SPVM_OP* op_constant = SPVM_OP_new_op(compiler, SPVM_OP_C_CODE_CONSTANT, op_cur->file, op_cur->line);
                           op_constant->uv.constant = op_cur->uv.constant;
                           
-                          op_cur->code = SPVM_OP_C_CODE_MALLOC;
+                          op_cur->code = SPVM_OP_C_CODE_NEW;
                           op_cur->first = op_constant;
                           op_cur->last = op_constant;
                           
@@ -881,7 +846,7 @@ void SPVM_OP_CHECKER_check(SPVM_COMPILER* compiler) {
                       
                       break;
                     }
-                    case SPVM_OP_C_CODE_MALLOC: {
+                    case SPVM_OP_C_CODE_NEW: {
                       SPVM_OP* op_type_or_constant = op_cur->first;
                       
                       if (op_cur->first->code == SPVM_OP_C_CODE_TYPE) {
@@ -916,7 +881,7 @@ void SPVM_OP_CHECKER_check(SPVM_COMPILER* compiler) {
                         assert(0);
                       }
                       
-                      // If MALLOC is not rvalue, temparary variable is created, and assinged.
+                      // If NEW is not rvalue, temparary variable is created, and assinged.
                       if (!op_cur->rvalue) {
                         assert(my_var_length <= SPVM_LIMIT_C_MY_VARS);
                         if (my_var_length == SPVM_LIMIT_C_MY_VARS) {
@@ -956,7 +921,7 @@ void SPVM_OP_CHECKER_check(SPVM_COMPILER* compiler) {
                         SPVM_OP* op_var = SPVM_OP_new_op_var_from_op_my_var(compiler, op_my_var);
                         
                         // Malloc op
-                        SPVM_OP* op_malloc = SPVM_OP_new_op(compiler, SPVM_OP_C_CODE_MALLOC, op_cur->file, op_cur->line);
+                        SPVM_OP* op_malloc = SPVM_OP_new_op(compiler, SPVM_OP_C_CODE_NEW, op_cur->file, op_cur->line);
                         
                         // Type parent is malloc
                         op_type_or_constant->moresib = 0;
@@ -968,7 +933,10 @@ void SPVM_OP_CHECKER_check(SPVM_COMPILER* compiler) {
                         op_assign->last = op_malloc;
                         op_assign->moresib = 0;
                         op_assign->sibparent = op_cur;
-                        
+
+                        op_assign->first->lvalue = 1;
+                        op_assign->last->rvalue = 1;
+
                         // Convert cur malloc op to var
                         op_cur->code = SPVM_OP_C_CODE_VAR;
                         op_cur->uv.var = op_var->uv.var;
@@ -1472,33 +1440,6 @@ void SPVM_OP_CHECKER_check(SPVM_COMPILER* compiler) {
                         SPVM_DYNAMIC_ARRAY_push(op_my_var_stack, op_cur);
                       }
                       
-                      // If left is object and right is not exists, append "= undef" code
-                      SPVM_TYPE* first_type = SPVM_OP_get_type(compiler, op_cur);
-                      
-                      // Assign undef if left value is object and right value is nothing
-                      if (first_type && !SPVM_TYPE_is_numeric(compiler, first_type) && !SPVM_OP_sibling(compiler, op_cur)) {
-                        // Only my declarations after subroutine arguments
-                        if (my_var->index >= sub->op_args->length) {
-                          SPVM_OP* op_assign = SPVM_OP_new_op(compiler, SPVM_OP_C_CODE_ASSIGN, op_cur->file, op_cur->line);
-                          
-                          SPVM_VAR* var = SPVM_VAR_new(compiler);
-                          SPVM_OP* op_name_var = SPVM_OP_new_op(compiler, SPVM_OP_C_CODE_NAME, op_cur->file, op_cur->line);
-                          op_name_var->uv.name = op_cur->uv.my_var->op_name->uv.name;
-                          var->op_name = op_name_var;
-                          var->op_my_var = op_cur;
-                          
-                          SPVM_OP* op_var = SPVM_OP_new_op(compiler, SPVM_OP_C_CODE_VAR, op_cur->file, op_cur->line);
-                          op_var->uv.var = var;
-                          
-                          SPVM_OP* op_undef = SPVM_OP_new_op(compiler, SPVM_OP_C_CODE_UNDEF, op_cur->file, op_cur->line);
-                          
-                          SPVM_OP_insert_child(compiler, op_assign, op_assign->last, op_var);
-                          SPVM_OP_insert_child(compiler, op_assign, op_assign->last, op_undef);
-                          
-                          SPVM_OP_insert_child(compiler, op_cur->sibparent, op_cur->sibparent->last, op_assign);
-                        }
-                      }
-                      
                       break;
                     }
                     case SPVM_OP_C_CODE_CALL_SUB: {
@@ -1666,7 +1607,7 @@ void SPVM_OP_CHECKER_check(SPVM_COMPILER* compiler) {
                         && op_term->code != SPVM_OP_C_CODE_ARRAY_ELEM
                         && op_term->code != SPVM_OP_C_CODE_CALL_FIELD
                         && op_term->code != SPVM_OP_C_CODE_CALL_SUB
-                        && op_term->code != SPVM_OP_C_CODE_MALLOC)
+                        && op_term->code != SPVM_OP_C_CODE_NEW)
                       {
                         SPVM_yyerror_format(compiler, "field invoker is invalid \"%s\" at %s line %d\n",
                           op_name->uv.name, op_cur->file, op_cur->line);
